## ecr.ui.color

src/ecr/ui/color.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    from prompt_toolkit import HTML

    def useRed(content: str)->HTML:
        return HTML(f'<obj fg="ansired">{content}</obj>')

    def useGreen(content: str)->HTML:
        return HTML(f'<obj fg="ansigreen">{content}</obj>')

    def useBlue(content: str)->HTML:
        return HTML(f'<obj fg="ansiblue">{content}</obj>')

    def useCyan(content: str)->HTML:
        return HTML(f'<obj fg="ansicyan">{content}</obj>')

    def useYellow(content: str)->HTML:
        return HTML(f'<obj fg="ansiyellow">{content}</obj>')